@@ -1,7 +1,7 @@
 ##
 #   Project: gespeaker - A GTK frontend for espeak  
 #    Author: Fabio Castelli <muflone@vbsimple.net>
-# Copyright: 2009-2013 Fabio Castelli
+# Copyright: 2009-2014 Fabio Castelli
 #   License: GPL-2+
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License as published by the Free
@@ -176,7 +176,17 @@ class EspeakFrontend(object):
   def loadMbrolaVoices(self, pathVoicesmb):
     "Load mbrola languages list"
     voicesmb = []
-    pathVoices = '/usr/share/espeak-data/voices/mb/'
+    espeak_data_paths = (
+      '/usr/share/espeak-data/voices/mb/',
+      '/usr/lib/x86_64-linux-gnu/espeak-data/voices/mb/',
+      '/usr/lib/i386-linux-gnu/espeak-data/voices/mb/',
+    )
+    for pathVoices in espeak_data_paths:
+      if os.path.isdir(pathVoices):
+        break
+    else:
+      print 'Cannot find any espeak-data voices folder, unable to detect MBROLA voices'
+      pathVoices = ''
     if not pathVoicesmb or not os.path.isdir(pathVoicesmb):
       pathVoicesmb = '/usr/share/mbrola'
     if os.path.isdir(pathVoices) and os.path.isdir(pathVoicesmb):
