@@ -1,7 +1,7 @@
 ##
 #   Project: gespeaker - A GTK frontend for espeak  
 #    Author: Fabio Castelli <muflone@vbsimple.net>
-# Copyright: 2009-2013 Fabio Castelli
+# Copyright: 2009-2014 Fabio Castelli
 #   License: GPL-2+
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License as published by the Free
@@ -25,7 +25,7 @@ from gettext import gettext as _
 cmdEspeak = '/usr/bin/espeak'
 argsEspeak = '-a %v -p %p -s %s -g %d -v %l -f %f --pho'
 cmdMbrola = '/usr/bin/mbrola'
-argsMbrola = '-e %l -'
+argsMbrola = '-v %v -e %l -'
 
 config = None
 confdir = os.path.join(xdg_config_home, 'gespeaker')
