@@ -1,7 +1,7 @@
 ##
 #   Project: gespeaker - A GTK frontend for espeak  
 #    Author: Fabio Castelli <muflone@vbsimple.net>
-# Copyright: 2009-2013 Fabio Castelli
+# Copyright: 2009-2014 Fabio Castelli
 #   License: GPL-2+
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License as published by the Free
@@ -365,12 +365,12 @@ class gespeakerUI(object):
       name=handlepaths.APP_TITLE,
       version=handlepaths.APP_VERSION,
       comment=_('A GTK frontend for espeak'),
-      copyright='Copyright 2009 Fabio Castelli',
+      copyright='Copyright 2009-2014 Fabio Castelli',
       license=handlepaths.read_text_file('doc', 'copyright'), 
-      website='http://code.google.com/p/gespeaker/',
-      website_label='Gespeaker',
-      authors=['Fabio Castelli <muflone@vbsimple.net>'],
-      translation=handlepaths.read_text_file('doc', 'translators'),
+      website='http://www.muflone.com/gespeaker/',
+      website_label='http://www.muflone.com/gespeaker/',
+      authors=['Fabio Castelli (Muflone) <muflone@vbsimple.net>'],
+      translation=handlepaths.read_text_file('doc', 'translators').replace('(at)', '@'),
       logo=handlepaths.get_app_logo(),
       icon=handlepaths.get_app_logo()
     )
@@ -477,6 +477,7 @@ class gespeakerUI(object):
         self.espeak.play(cmd, self.cmdPlayer, self.recordToFile)
       else:
         args = {
+          '%v': str(int(self.hscVolume.get_value())/100.), 
           '%l': '%s/%s/%s' % (
             Settings.get('VoicesmbPath'), 
             language.replace('mb-', '', 1),
